----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    10:19:10 06/29/2007 
-- Design Name: Temperature Sensor Box
-- Module Name:    Temp_box - Temp_box_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Testing box for temperature sensor controller & emulator
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_box is
    Port ( CLK : in  STD_LOGIC;								-- clock
           iRST : in  STD_LOGIC;								-- reset
           Go : in  STD_LOGIC;								-- pulse to start
           Din : in  STD_LOGIC_VECTOR (9 downto 0);	-- parallel data in
           Dout : out  STD_LOGIC_VECTOR (9 downto 0);	-- parallel data out
           Err : out  STD_LOGIC);							-- timing error flag
end Temp_box;

architecture Temp_box_arch of Temp_box is

	component Temp_cont
		Port (	CLK : in  STD_LOGIC;
					iRST : in  STD_LOGIC;
					Go : in  STD_LOGIC;
					Din : in  STD_LOGIC;
					SCLK: out STD_LOGIC;
					CE : out STD_LOGIC;
					Q : out  STD_LOGIC_VECTOR (9 downto 0));
	end component;
	
	component Temp_emul
		Port (	RST : in STD_LOGIC;
					SCLK : in  STD_LOGIC;
					SDO : out  STD_LOGIC;
					CE : in  STD_LOGIC;
					Error : out  STD_LOGIC;
					Din : in  STD_LOGIC_VECTOR (9 downto 0));
	end component;
	
	signal SData : STD_LOGIC;
	signal SCLK : STD_LOGIC;
	signal CE : STD_LOGIC;

begin

	u1: Temp_cont port map (CLK, iRST, Go, SData, SCLK, CE, Dout);
	u2: Temp_emul port map (iRST, SCLK, SData, CE, Err, Din);

end Temp_box_arch;

