----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    17:13:26 06/28/2007 
-- Design Name: Counter for Temperature Sensor Controller
-- Module Name:    Temp_cntr - Temp_cntr_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Counter, maintains timing on assorted enable lines
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_cntr is
    Port ( CLK : in  STD_LOGIC;		-- clock
           RST : in  STD_LOGIC;		-- reset
           Go : in  STD_LOGIC;		-- pulse to start counting
			  CE : out STD_LOGIC;		-- chip enable
           En : out  STD_LOGIC);		-- shift enable
end Temp_cntr;

architecture Temp_cntr_arch of Temp_cntr is

	signal count : STD_LOGIC_VECTOR (4 downto 0);

begin

	cnt : process (CLK, RST)
	begin
		if (RST = '0') then
		-- asynchronous, active-low reset
			count <= "00000";
		else
			if (rising_edge(CLK)) then
				if (count = "00000") then
					if (Go = '1') then
					-- begin counting
						count <= count + 1;
					else
						count <= count;
					end if;
				else
					if (count = "10000") then
					-- loop count after 17 cycles
						count <= "00000";
					else
						count <= count + 1;
					end if;
				end if;
			else
				count <= count;
			end if;
		end if;
	end process cnt;
	
	En <= (not count(3) and (count(2) or count(1) or count(0))) or (count(3) and not count(2));
	-- high for 11 cycles
	CE <= count(4) or count(3) or count(2) or count(1) or count(0);
	-- high for 16 cycles

end Temp_cntr_arch;

