----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    16:58:35 06/28/2007 
-- Design Name: Shift Register for Temperature Sensor Controller
-- Module Name:    Temp_cshift - Temp_cshift_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Serial-in, parallel-out shift register
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_cshift is
    Port ( CLK : in  STD_LOGIC;								-- clock
           RST : in  STD_LOGIC;								-- reset
           En : in  STD_LOGIC;								-- shift enable
           Din : in  STD_LOGIC;								-- serial data in
           Q : out  STD_LOGIC_VECTOR (9 downto 0));	-- parallel data out
end Temp_cshift;

architecture Temp_cshift_arch of Temp_cshift is

	signal data : STD_LOGIC_VECTOR (9 downto 0);			-- internal register data

begin

	shifter : process (CLK, RST)
	begin
		if (RST = '0') then
		-- asynchronous, active-low reset
			data <= "0000000000";
		else
			if (rising_edge(CLK)) then
				if (En = '1') then
				-- shift
					for i in 0 to 8 loop
						data(i+1) <= data(i);
					end loop;
					data(0) <= Din;
				else
				-- hold
					data <= data;
				end if;
			else
				data <= data;
			end if;
		end if;
	end process shifter;
	
	Q <= data;

end Temp_cshift_arch;

