----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    14:23:43 06/27/2007 
-- Design Name: Temperature Sensor Emulator
-- Module Name:    Temp_emul - Temp_emul_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Emulator for Temperature Sensor (AD7314)
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_emul is
    Port ( RST : in STD_LOGIC;								-- reset
           SCLK : in  STD_LOGIC;								-- clock
           SDO : out  STD_LOGIC;								-- serial data out
           CE : in  STD_LOGIC;								-- chip enable
           Error : out  STD_LOGIC;							-- error flag
           Din : in  STD_LOGIC_VECTOR (9 downto 0));	-- parallel data in
end Temp_emul;

architecture Temp_emul_arch of Temp_emul is

	component Temp_delay
		Port (	CLK : in  STD_LOGIC;
					SigIn : in  STD_LOGIC;
					SigOut : out  STD_LOGIC);
	end component;

	component Temp_err
		Port (	CLK : in  STD_LOGIC;
					RST : in STD_LOGIC;
					EN : in  STD_LOGIC;
					Err : out  STD_LOGIC);
	end component;
	
	component Temp_shift
		Port (	CLK : in  STD_LOGIC;
					RST : in STD_LOGIC;
					Sh : in  STD_LOGIC;
					ParIn : in  STD_LOGIC_VECTOR (10 downto 0);
					SerOut : out  STD_LOGIC);
	end component;
	
	signal paraReg : STD_LOGIC_VECTOR (10 downto 0);
	--signal delEn : STD_LOGIC;
	
begin

	paraReg(10) <= '0';				-- connect signals
	paraReg(9 downto 0) <= Din;

	u1: Temp_err	port map (SCLK, RST, CE, Error);				-- connect components
	u2: Temp_shift	port map (SCLK, RST, CE, paraReg, SDO);
	--u2: Temp_shift	port map (SCLK, RST, delEn, paraReg, SDO);
	--u3: Temp_delay port map (SCLK, CE, delEn);

end Temp_emul_arch;

