----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    11:42:37 06/27/2007 
-- Design Name: Error Counter for Temperature Sensor Emulator
-- Module Name:    Temp_err - Temp_err_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Counts length of Enable pulse and raises an error flag if the
--					 plus is not 16 cycles long
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_err is
    Port ( CLK : in  STD_LOGIC;		-- clock
           RST : in STD_LOGIC;		-- reset
			  EN : in  STD_LOGIC;		-- chip enable
           Err : out  STD_LOGIC);	-- error flag
end Temp_err;

architecture Temp_err_arch of Temp_err is

	signal IntCnt : STD_LOGIC_VECTOR (4 downto 0);
	signal last : STD_LOGIC;
	signal flag : STD_LOGIC;

begin

	saveEn : process (CLK, EN)
	-- save the previous value of the enable line
	begin
		if (rising_edge(CLK)) then
			last <= EN;
		else
			last <= last;
		end if;
	end process saveEn;
	
	flagger : process (CLK, EN, RST)
	begin
		if (RST = '0') then
		-- asynchronous, active-low reset
			IntCnt <= "00000";
			flag <= '0';
		else
			if (rising_edge(CLK)) then
				if ((last = '1') and (EN = '0')) then
					if (IntCnt = "10000") then
					-- if enable falls on the 16th cycle: no error
						flag <= '0';
					else
						flag <= '1';
					end if;
					IntCnt <= "00000";
				else
					if ((last = '0') and (EN = '1')) then
					-- reset flag at the beginning of a new enable pulse
						flag <= '0';
					else
						flag <= flag;
					end if;
					if (EN = '1') then
					-- count the pulse length
						IntCnt <= IntCnt + 1;
					else
						IntCnt <= IntCnt;
					end if;
				end if;
			else
				flag <= flag;
				IntCnt <= IntCnt;
			end if;
		end if;
	end process flagger;
	
	--Cnt <= IntCnt(3 downto 0);
	Err <= flag;

end Temp_err_arch;

