----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    14:17:55 06/27/2007 
-- Design Name: Control Register for Temperature Sensor Emulator
-- Module Name:    Temp_reg - Behavioral 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: A 10-bit parallel-load parallel-write register
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_reg is
    Port ( CLK : in  STD_LOGIC;
           RST : in STD_LOGIC;
			  EN : in  STD_LOGIC;
           Din : in  STD_LOGIC_VECTOR (9 downto 0);
           Dout : out  STD_LOGIC_VECTOR (10 downto 0));
end Temp_reg;

architecture Behavioral of Temp_reg is

	signal data : STD_LOGIC_VECTOR (10 downto 0);

begin

	reg : process (CLK, EN)
	begin
		if (RST = '0') then
			data <= "00000000000";
		else
			if (rising_edge(CLK)) then
				if (EN = '1') then
					data(10) <= '0';
					data(9 downto 0) <= Din (9 downto 0);
				else
					data <= data;
				end if;
			else
				data <= data;
			end if;
		end if;
	end process reg;
	
	Dout <= data;
	
end Behavioral;

