----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    10:30:57 06/27/2007 
-- Design Name: Shift Register for Temperature Sensor Emulator
-- Module Name:    Temp_shift - Temp_shift_arch 
-- Project Name: Temperature Sensor
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: An 11-bit shift register to convert parallel to serial
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Temp_shift is
    Port ( CLK : in  STD_LOGIC;									-- Clock
           RST : in STD_LOGIC;									-- Asynch, active-low reset
			  Sh : in  STD_LOGIC;									-- Shift (active-high), Load (active-low)
           ParIn : in  STD_LOGIC_VECTOR (10 downto 0);	-- Parallel load inputs
           SerOut : out  STD_LOGIC);							-- Serial read outputs
end Temp_shift;

architecture Temp_shift_arch of Temp_shift is

	signal data : STD_LOGIC_VECTOR(10 downto 0);
	signal line : STD_LOGIC;

begin

	shift : process (CLK, RST, Sh)
	begin
		if (RST = '0') then
		-- asynchronous, active-low reset to zero out register
			data <= "00000000000";
		else
			if (rising_edge(CLK)) then
				if (Sh = '1') then
				-- shift
					line <= data(10);
					for i in 0 to 9 loop
						data(i+1) <= data(i);
					end loop;
				else
				-- load, output high-Z
					line <= 'Z';
					data <= ParIn;
				end if;
			else
				line <= line;
				data <= data;
			end if;
		end if;
	end process shift;
	
	SerOut <= line;

end Temp_shift_arch;

